<div align="center">

<img src="https://github.com/markmelnic/pyapibp/blob/main/res/logo.png" alt="PYAPIBP Logo" width="400"/>

# `pyapibp` - Python boilerplate code generator to easily start building API\'s

![PyPI Version](https://img.shields.io/pypi/pyversions/dash.svg)
![PyPI Version](https://img.shields.io/pypi/v/pyapibp.svg)
![License](https://img.shields.io/pypi/l/pyapibp.svg)

</div>

This python script generates a folder structure along all default files for an API framework in the current directory, optionally creating a new one.

Currently supported frameworks:

- Flask
- FastAPI

Work in progress:

- Django

## Short backstory

When getting started on building an API, I found myself looking up an older project, copying the folder structure along the files and their contents. Then, remembering what environment variables I should include in the .env and their defaults for a local project. All in all, it was repetitive and annoying. Then let's be honest, why spend 5 minutes doing a repetitive task every now and then if you can spend 3 hours trying to automate it. Anyway, I hope you find this tool useful, and if you did, leave a star just so I know you found this tool useful.

## Installation

Installation is done using pip using the following command:

    pip install pyapibp

## Usage

In the desired folder, run the following command:

    $ pyapibp

That's about it, follow the instructions, choose your options and tada, you are ready to code!

I will write a more detailed description of the options after adding more frameworks, flags *etc... etc...*, but for now, enjoy.
